Documentation
¶
Index ¶
Constants ¶
const ( // DefaultPersistentVolumeClaimSize represents default size of PVC created for a Pipeline, // specified in bytes (eg. 5Mi = 5MiB = 5 * 1024 * 1024) DefaultPersistentVolumeClaimSize int64 = 5 * 1024 * 1024 )
const (
DefaultWaitingTimeout = 120 * time.Second
)
Variables ¶
var ( // ErrRuntimeRequired indicates the required value of Function Runtime was not provided ErrRuntimeRequired = errors.New("runtime is required to build") ErrBuilpacksNotSupported = errors.New("additional Buildpacks are not supported for on cluster build") )
Functions ¶
func NewTektonClientAndResolvedNamespace ¶ added in v0.23.0
func NewTektonClientAndResolvedNamespace(defaultNamespace string) (*v1beta1.TektonV1beta1Client, string, error)
func NewTektonClientset ¶
Types ¶
type ErrRuntimeNotSupported ¶ added in v0.25.0
type ErrRuntimeNotSupported struct {
Runtime string
}
func (ErrRuntimeNotSupported) Error ¶ added in v0.25.0
func (e ErrRuntimeNotSupported) Error() string
type Opt ¶
type Opt func(*PipelinesProvider)
func WithCredentialsProvider ¶
func WithCredentialsProvider(credentialsProvider docker.CredentialsProvider) Opt
func WithNamespace ¶
func WithPipelineDecorator ¶ added in v0.25.0
func WithPipelineDecorator(decorator PipelineDecorator) Opt
func WithProgressListener ¶
func WithProgressListener(pl fn.ProgressListener) Opt
func WithVerbose ¶ added in v0.23.0
type PipelineDecorator ¶ added in v0.25.0
type PipelinesProvider ¶
type PipelinesProvider struct {
// contains filtered or unexported fields
}
func NewPipelinesProvider ¶
func NewPipelinesProvider(opts ...Opt) *PipelinesProvider
func (*PipelinesProvider) Run ¶
Run creates a Tekton Pipeline and all necessary resources (PVCs, Secrets, SAs,...) for the input Function. It ensures that all needed resources are present on the cluster so the PipelineRun can be initialized. After the PipelineRun is being intitialized, the progress of the PipelineRun is being watched and printed to the output.
Click to show internal directories.
Click to hide internal directories.